#!/bin/bash

SUBJ="/C=DE/ST=Franconia/L=Nuremberg/O=SUSE Linux Products GmbH/CN=ALPA-CA/emailAddress=alp-automotive@suse.de"
PKI="/etc/pki/kuksa-val/"
genCAKey() {
    openssl genrsa -out ${PKI}/CA.key 2048
}


genCACert() {
    openssl req -key ${PKI}CA.key -new -out ${PKI}/CA.csr -subj "${SUBJ}"
    openssl x509 -signkey ${PKI}CA.key -in ${PKI}/CA.csr -req -days 3650 -out "${PKI}"/CA.pem
}

genKey() {
    openssl genrsa -out ${PKI}/$1.key 2048
}

genCert() {
    openssl req -new -key ${PKI}/$1.key -out ${PKI}/$1.csr -passin pass:"temp" -subj "${SUBJ}"
    openssl x509 -req -in ${PKI}/$1.csr -extfile <(printf "subjectAltName=DNS:$1,DNS:localhost,IP:127.0.0.1") -CA ${PKI}/CA.pem -CAkey ${PKI}/CA.key -CAcreateserial -days 1460 -out ${PKI}/$1.pem
    openssl verify -CAfile ${PKI}/CA.pem ${PKI}/$1.pem
}

set -e
# Check if the CA is available, else make CA certificates
if [ -f "${PKI}/CA.key" ]; then
    echo "Existing ${PKI}/CA.key will be used"
else
    echo "No ${PKI}/CA.key found, will generate new key"
    genCAKey
    rm -f ${PKI}/CA.pem
    echo ""
fi

# Check if the CA.pem is available, else generate a new CA.pem
if [ -f "${PKI}/CA.pem" ]; then
    echo "${PKI}/CA.pem will not be regenerated"
else
    echo "No ${PKI}/CA.pem found, will generate new CA.pem"
    genCACert
    echo ""
fi


for i in Server Client;
do
    if [ -f ${PKI}/$i.key ]; then
        echo "Existing $i.key will be used"
    else
        echo "No ${PKI}/$i.key found, will generate new key"
        genKey $i
    fi
    echo ""
    echo "Generating $PKI/$i.pem"
    genCert $i
    echo "Making certificates available for others (agl-driver)"
    chmod 0644 $PKI/$i.pem
    echo ""
done


